import 'dart:convert';

import 'package:agschat_example/global.dart';
import 'package:agschat_example/helper/logger.dart';
import 'package:agschat_example/helper/network_connection.dart';
import 'package:agschat_example/view/widgets/comman.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;

class Webservice {
  static postRequest(
      {@required uri,
      baseUrl, // require for login, and other API url get from Login Response
      body,
      header,
      jsonEncoded = true,
      bool hasBearer = false,
      Function(dynamic responseBody)? onSuccess,
      Function(dynamic error)? onFailure,
      Function? onTimeout,
      Function? onConnectionFailed}) async {
    bool isConnected = await NetworkConnection.isConnectedNetwork();
    if (!isConnected) {
      if (onConnectionFailed != null)
        onConnectionFailed("Check your internet connection and try again");
      Common.getSnackToast(
        title: 'Connection Error',
        message: "Check your internet connection and try again",
      );
      return;
    }

    if (hasBearer) {
      header = {
        'Content-Type': 'application/json',
        'Authorization': 'Bearer',
      };
    } else {
      if (header == null) {
        header = {'Content-Type': 'application/json'};
      }
    }

    if (jsonEncoded) {
      body = jsonEncode(body);
    }

    if (baseUrl == null) {
      baseUrl = Global.BASE_URL;
    }
    var url = baseUrl + uri;

    //make sure body should not have integer values, below body accept only String values.
    //make sure here body only accept Map type data till you not set 'Content-Type': 'application/json',
    http.post(Uri.parse(url), body: body, headers: header).then((response) {
      Log.displayResponse(payload: body, res: response, requestType: 'POST');
      var bodyData = jsonDecode(response.body);
      if (bodyData['status'] == -1) {
      } else if (onSuccess != null) onSuccess(response.body);
    }).catchError((error) {
      print('Error : catchError $error');
      print(url);
      Common.getSnackToast(
          message: error.toString(),
          colorText: Colors.white,
          backgroundColor: Colors.red);

      if (onFailure != null) onFailure(error);
    }).timeout(Duration(seconds: 20), onTimeout: () {
      print('$url');
      print('Error : TimeOut');

      if (onTimeout != null) onTimeout();
    });
  }
}
