import 'package:agschat_example/constants.dart';
import 'package:agschat_example/core/services/stream_socket.dart';
import 'package:agschat_example/helper/custom_styles.dart';
import 'package:agschat_example/helper/images.dart';
import 'package:agschat_example/helper/utilites.dart';
import 'package:agschat_example/view/contact_list_view.dart';
import 'package:agschat_example/view/message_view.dart';
import 'package:agschat_example/view/profile_view.dart';
import 'package:agschat_example/view/widgets/comman.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ChatsListView extends StatefulWidget {
  const ChatsListView({Key? key}) : super(key: key);

  _ChatsListViewState createState() => _ChatsListViewState();
}

class _ChatsListViewState extends State<ChatsListView> {
  TextEditingController searchController = TextEditingController();
  List snap = [];
  String searchText = '';

  @override
  void initState() {
    super.initState();
    getChatsList();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
        child: Column(
          children: [
            appBar(),
            Padding(
              padding: const EdgeInsets.only(left: 20, right: 20, top: 8),
              child: Row(
                children: [
                  Expanded(
                    child: TextField(
                      controller: searchController,
                      onChanged: (val) {
                        setState(() {
                          searchText = val;
                        });
                      },
                      decoration: InputDecoration(
                        hintText: "Search chat",
                        hintStyle: CustomTextStyles.medium(
                            fontSize: 14.0, fontColor: Colors.black38),
                        filled: true,
                        fillColor: const Color(0xffEEEEEF),
                        border: searchCommonBorderStyle,
                        enabledBorder: searchCommonBorderStyle,
                        disabledBorder: searchCommonBorderStyle,
                        focusedBorder: searchCommonBorderStyle,
                        focusedErrorBorder: searchCommonBorderStyle,
                        errorBorder: searchCommonBorderStyle,
                        contentPadding:
                            const EdgeInsets.only(left: 6, right: 6),
                        prefixIcon: const Padding(
                            padding: EdgeInsetsDirectional.only(start: 6.0),
                            child: Icon(Icons.search)),
                      ),
                    ),
                  ),
                  const SizedBox(width: 8),
                  InkWell(
                    onTap: () {
                      setState(() {
                        searchText = '';
                        searchController.clear();
                      });
                    },
                    child: Text("Cancel",
                        style: CustomTextStyles.medium(
                            fontSize: 14.0, fontColor: Colors.black38)),
                  )
                ],
              ),
            ),
            const Padding(
              padding: EdgeInsets.only(
                top: 4,
              ),
              child: Divider(
                color: Color(0xffd4d4d4),
                thickness: 1,
              ),
            ),
            Expanded(
              child: StreamBuilder(
                  stream: chatListSoket.getResponse,
                  builder:
                      (BuildContext context, AsyncSnapshot<dynamic> snapshot) {
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return const Center(child: CircularProgressIndicator());
                    }
                    snap = snapshot.data as List;
                    if (searchText.isNotEmpty) {
                      snap = snap.where((element) {
                        return element['name']
                            .toString()
                            .toLowerCase()
                            .contains(searchText.toLowerCase());
                      }).toList();
                    }
                    return snap.isEmpty
                        ? const Center(
                            child: Text("Data not found"),
                          )
                        : ListView.separated(
                            padding: const EdgeInsets.symmetric(vertical: 20),
                            itemBuilder: (context, index) {
                              return chatItem(snap[index]);
                            },
                            separatorBuilder: (context, index) {
                              return const Padding(
                                padding: EdgeInsets.only(top: 4, bottom: 4),
                                child: Divider(
                                  color: Color(0xffd4d4d4),
                                  thickness: 1.5,
                                ),
                              );
                            },
                            itemCount: snap.length);
                  }),
            ),
          ],
        ),
      ),
    );
  }

  Widget appBar() {
    return Container(
      color: const Color(0xffE5E5EA),
      padding: const EdgeInsets.symmetric(vertical: 10, horizontal: 10),
      child: Row(
        children: [
          GestureDetector(
            onTap: () {
              Get.to(() => const ProfileView());
            },
            child: Common.profileNetworkImage(
                borderRadius: 60.0, height: 40.0, width: 40.0, imageUrl: ""),
          ),
          const Expanded(
            child: Text(""),
          ),
          IconButton(
            icon: const Icon(Icons.group_add, color: Colors.black),
            onPressed: () {
              Get.to(() => ContactListView(forMakeGroup: true));
            },
          ),
          IconButton(
            icon: Icon(Icons.account_circle),
            onPressed: () {
              Get.to(() => ContactListView(forMakeGroup: false));
            },
          ),
        ],
      ),
    );
  }

  // Common border for textField
  var searchCommonBorderStyle = const OutlineInputBorder(
    borderSide: BorderSide(
      color: Color(0xffE6E6E6),
    ),
  );

  chatItem(data) {
    var count = 0;
    print(data);
    print("DATA");
    if (data != null) {
      data['readCount'].forEach((va) {
        if (va['userId'] == myUserId) {
          count = va['unreadCount'];
        }
      });
    }
    return Padding(
      padding: const EdgeInsets.only(left: 16, right: 16),
      child: InkWell(
        onTap: () {
          Get.to(() => MessageView(), arguments: [
            myUserId,
            data,
          ]);
          // Get.to(() => Player(
          //       audioFile:
          //           "https://www2.cs.uic.edu/~i101/SoundFiles/BabyElephantWalk60.wav",
          //     ));
        },
        child: Row(
          children: [
            Common.profileNetworkImage(
                borderRadius: 64.0,
                height: 64.0,
                width: 64.0,
                placeHolder: data['isGroup']
                    ? ImageResource.groupPlaceHolder
                    : ImageResource.profilePlaceHolder,
                imageUrl: data['groupImage']),
            const SizedBox(width: 10),
            Expanded(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      Expanded(
                        child: Text(data['name'],
                            style: CustomTextStyles.semiBold(
                                fontSize: 14.0, fontColor: Colors.black)),
                      ),
                      const SizedBox(width: 10),
                      data['recentMessage']['timeMilliSeconds'] == null
                          ? SizedBox.shrink()
                          : Text(
                              Utilities.convertTimeStampToDate(
                                  data['recentMessage']['timeMilliSeconds']
                                          ['seconds'] ??
                                      ""),
                              style: CustomTextStyles.normal(
                                  fontSize: 10.0, fontColor: Colors.black),
                            )
                    ],
                  ),
                  const SizedBox(height: 6),
                  data['isGroup']
                      ? Text(
                          "Start your conversation",
                          style: CustomTextStyles.normal(
                              fontSize: 12.0, fontColor: Colors.grey),
                        )
                      : Row(
                          children: [
                            data['recentMessage']['type'] == "text"
                                ? const SizedBox.shrink()
                                : Image.asset(
                                    data['recentMessage']['type'] == "audio"
                                        ? ImageResource.audioIc
                                        : data['recentMessage']['type'] ==
                                                "video"
                                            ? ImageResource.videoIc
                                            : data['recentMessage'] == "image"
                                                ? ImageResource.imageIc
                                                : ImageResource.documentIc,
                                    height: 20,
                                    width: 20,
                                  ),
                            Expanded(
                              child: Text(
                                  data['recentMessage']['type'] == "text"
                                      ? data['recentMessage']['message']
                                      : " ${data['recentMessage']['type']}",
                                  style: CustomTextStyles.normal(
                                      fontSize: 12.0, fontColor: Colors.black)),
                            ),
                            count == 0
                                ? const SizedBox.shrink()
                                : CircleAvatar(
                                    backgroundColor: Colors.red,
                                    radius: 10,
                                    child: Text("$count",
                                        style: CustomTextStyles.medium(
                                            fontSize: 10.0,
                                            fontColor: Colors.white)),
                                  )
                          ],
                        )
                ],
              ),
            )
          ],
        ),
      ),
    );
  }
}
