import 'dart:io';
import 'dart:ui';

import 'package:agschat_example/constants.dart';
import 'package:agschat_example/core/services/stream_socket.dart';
import 'package:agschat_example/helper/custom_styles.dart';
import 'package:agschat_example/helper/images.dart';
import 'package:agschat_example/helper/utilites.dart';
import 'package:agschat_example/model/message_model.dart';
import 'package:agschat_example/view/contect_info_view.dart';
import 'package:agschat_example/view/widgets/comman.dart';
import 'package:agschat_example/view/widgets/group_info_view.dart';
import 'package:agschat_example/view/widgets/image_view_dialog.dart';
import 'package:agschat_example/view/widgets/video_player.dart';
import 'package:better_open_file/better_open_file.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:geolocator/geolocator.dart';
import 'package:get/get.dart';
import 'package:grouped_list/grouped_list.dart';
import 'package:image_picker/image_picker.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:video_thumbnail/video_thumbnail.dart';

import 'widgets/audio_play_dialog.dart';

class MessageView extends StatefulWidget {
  const MessageView({Key? key}) : super(key: key);

  @override
  _MessageViewState createState() => _MessageViewState();
}

class _MessageViewState extends State<MessageView> {
  final ScrollController _scrollChatController = ScrollController();
  var name = "".obs;
  var profilePic = "".obs;
  var grpId = "";
  List messageData = [];
  var info;
  @override
  void initState() {
    if (Get.arguments != null) {
      var id = Get.arguments[0];
      info = Get.arguments[1];
      grpId = Get.arguments[1]['groupId'];
      name.value = Get.arguments[1]['name'];
      profilePic.value = Get.arguments[1]['groupImage'];
      joinGroup(grpId);
      getPreviousMessages(id: id, grpId: grpId);
      receiveMessage();
    }
    super.initState();
  }

  receiveMessage() {
    socket.on('receive-message', (datas) {
      print("Message receive $datas");
      var data = {
        'type': datas["type"],
        'image': datas["image"],
        'thumbnail': datas["thumbnail"],
        'audio': datas["audio"],
        "base64Thumbnail": "",
        "document": datas["document"],
        "isRead": true,
        "message": datas["msg"],
        'msgId': "10",
        "readBy": "",
        "secretKey": "",
        "sentAt": {
          'seconds': (DateTime.now().millisecondsSinceEpoch ~/ 1000),
          "nanoseconds": ""
        },
        "sentBy": "6270fff1b2000e317f955d75",
        "video": datas['video'],
      };
      Future.delayed(Duration.zero);
      setState(() {
        messageData.add(data);
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Scaffold(
          body: Container(
        decoration: const BoxDecoration(
            color: Colors.white,
            image: DecorationImage(
              image: ExactAssetImage(ImageResource.chatBg),
              fit: BoxFit.cover,
            )),
        child: Column(
          children: [
            appBar(),
            Expanded(
              child: StreamBuilder(
                  stream: messageSocket.getResponse,
                  builder:
                      (BuildContext context, AsyncSnapshot<dynamic> snapshot) {
                    if (snapshot.connectionState == ConnectionState.waiting) {
                      return const Center(child: CircularProgressIndicator());
                    }

                    messageData = snapshot.data;

                    return snapshot.data == null
                        ? const SizedBox.shrink()
                        : GroupedListView<dynamic, String>(
                            elements: messageData,
                            groupBy: (element) =>
                                Utilities.convertTimeStampToDate(
                                    element['sentAt']['seconds'],
                                    formate: 'yyyy-MM-dd'),
                            order: GroupedListOrder.DESC,
                            reverse: true,
                            controller: _scrollChatController,
                            stickyHeaderBackgroundColor: Colors.transparent,
                            floatingHeader: true,
                            separator: const SizedBox(height: 0),
                            useStickyGroupSeparators: true,
                            groupSeparatorBuilder: (value) {
                              return groupSapeatorItem(value);
                            },
                            indexedItemBuilder: (context, item, index) {
                              MessagesModel chat = MessagesModel();
                              SentAt sentAt = SentAt();
                              sentAt = SentAt(
                                  seconds: item['sentAt']['seconds'],
                                  nanoseconds: item['sentAt']['seconds']);
                              chat = MessagesModel(
                                type: item['type'],
                                image: item['image'],
                                thumbnail: item['thumbnail'],
                                audio: item['audio'],
                                base64Thumbnail: item['base64Thumbnail'],
                                document: item['document'],
                                isRead: item['isRead'],
                                message: item['message'],
                                msgId: item['msgId'],
                                readBy: item['readyBy'],
                                secretKey: item['secretKey'],
                                sentAt: sentAt,
                                sentBy: item['sentBy'],
                                video: item['video'],
                                // viewBy: item['viewBy'],
                              );
                              return messageItem(chat, index);
                            },
                          );
                  }),
            ),
            messageSendView(),
          ],
        ),
      )),
    );
  }

  groupSapeatorItem(value) {
    String date = ChatDateFormatter().groupChatDateHeader(value);
    return SizedBox(
      height: 40,
      child: Align(
        alignment: Alignment.center,
        child: Container(
          padding: const EdgeInsets.symmetric(vertical: 8, horizontal: 10),
          decoration: const BoxDecoration(
            color: Colors.white,
            borderRadius: BorderRadius.all(Radius.circular(5.0)),
          ),
          child: Text(
            date,
            style: CustomTextStyles.normal(
                fontSize: 10.0, fontColor: Colors.black),
            textAlign: TextAlign.center,
          ),
        ),
      ),
    );
  }

  Widget appBar() {
    return SafeArea(
      child: Container(
        color: const Color(0xffE5E5EA),
        padding: const EdgeInsets.symmetric(vertical: 10, horizontal: 0),
        child: Row(
          children: [
            IconButton(
                onPressed: () {
                  Get.back();
                },
                icon: const Icon(Icons.arrow_back_outlined)),
            GestureDetector(
              onTap: () {
                if (info['isGroup']) {
                  Get.to(() => const GroupInfoView(), arguments: info);
                } else {
                  Get.to(() => const ContactInfoView());
                }
              },
              child: Common.profileNetworkImage(
                borderRadius: 60.0,
                height: 40.0,
                width: 40.0,
                placeHolder: info['isGroup']
                    ? ImageResource.groupPlaceHolder
                    : ImageResource.profilePlaceHolder,
                imageUrl: profilePic.value,
              ),
            ),
            Expanded(
              child: GestureDetector(
                onTap: () {
                  if (info['isGroup']) {
                    Get.to(() => const GroupInfoView(), arguments: info);
                  } else {
                    Get.to(() => const ContactInfoView());
                  }
                },
                child: Text(" ${name.value}",
                    style: CustomTextStyles.semiBold(
                        fontSize: 18.0, fontColor: Colors.black)),
              ),
            ),
            PopupMenuButton<int>(
              icon: const Icon(Icons.more_vert_outlined),
              itemBuilder: (context) => [
                PopupMenuItem(
                  onTap: () async {
                    await Future.delayed(const Duration(milliseconds: 10));
                    if (info['isGroup']) {
                      Get.to(() => const GroupInfoView(), arguments: info);
                    } else {
                      Get.to(() => const ContactInfoView());
                    }
                  },
                  value: 1,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text(
                        info['isGroup'] ? "Group info" : "Contact info",
                        style: CustomTextStyles.medium(
                            fontSize: 16.0, fontColor: Colors.black),
                      ),
                      const Icon(Icons.person),
                    ],
                  ),
                ),
                PopupMenuItem(
                  value: 2,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text(
                        "Delete chat",
                        style: CustomTextStyles.medium(
                            fontSize: 16.0, fontColor: Colors.black),
                      ),
                      const Icon(Icons.delete),
                    ],
                  ),
                ),
                PopupMenuItem(
                  value: 3,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text(
                        "Clear chat",
                        style: CustomTextStyles.medium(
                            fontSize: 16.0, fontColor: Colors.black),
                      ),
                      const Icon(Icons.message_outlined),
                    ],
                  ),
                ),
              ],
              offset: const Offset(0, 50),
              color: Colors.white70,
              elevation: 2,
            ),
          ],
        ),
      ),
    );
  }

  messageItem(MessagesModel chat, index) {
    return InkWell(
      onLongPress: () {
        // confirmationDialog(
        //     title: 'Delete Message',
        //     message: "Are you sure, you want to \n delete this Message ?",
        //     confirmButtonText: 'Delete',
        //     cancelButtonText: 'No',
        //     onConfirmPressed: () async {
        //       // onClear.value = true;
        //       CommonWidgets.hideDialog();
        //       CommonWidgets.apiLoader(asyncCall: () async {
        //         await uc.fStore
        //             .deleteSingleChatMessage(
        //             groupId: opponentUserModel?.groupId,
        //             msgId: chat.msgId)
        //             .catchError((onError) {
        //           CommonWidgets.hideLoader();
        //           uc.listViewRefreshCounter.value++;
        //         });
        //         CommonWidgets.hideLoader();
        //         uc.listViewRefreshCounter.value++;
        //       });
        //     });
      },
      child: Padding(
        padding: EdgeInsets.only(
          left: chat.sentBy == myUserId ? 100.0 : 10,
          right: chat.sentBy == myUserId ? 10 : 80,
          top: 10,
          bottom: 10,
        ),
        child: Row(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: chat.sentBy == myUserId
              ? MainAxisAlignment.end
              : MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.end,
          children: [
            // Visibility(
            //   child: Text('${uc.chatItemRefresher.value}'),
            //   visible: false,
            // ),
            const SizedBox(width: 6),
            Expanded(
              child: Column(
                crossAxisAlignment: chat.sentBy == myUserId
                    ? CrossAxisAlignment.end
                    : CrossAxisAlignment.start,
                children: [
                  Container(
                    padding: EdgeInsets.all(chat.type == "typing" ? 6 : 8),
                    decoration: BoxDecoration(
                      color: chat.sentBy == myUserId
                          ? const Color(0xff8EB4C9).withOpacity(0.8)
                          : Colors.white,
                      // themeLightBlue,
                      borderRadius: BorderRadius.circular(6),
                    ),
                    child: Padding(
                      padding: const EdgeInsets.all(0.0),
                      child: messageType(chat, index),
                    ),
                  ),
                  const SizedBox(
                    height: 8,
                  ),
                  Text(
                    Utilities.convertTimeStampToTime(chat.sentAt!.seconds),
                    textAlign: chat.sentBy == myUserId
                        ? TextAlign.right
                        : TextAlign.left,
                    style: CustomTextStyles.normal(
                        fontSize: 8.0, fontColor: Colors.black),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }

  messageType(MessagesModel chat, index) {
    print(chat);
    var fileName;
    if (chat.type == "text") {
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Text(chat.message!,
              style: CustomTextStyles.medium(
                  fontSize: 12.0, fontColor: Colors.black),
              textAlign:
                  chat.sentBy == myUserId ? TextAlign.right : TextAlign.left),
        ],
      );
    } else if (chat.type == "audio") {
      var encodedFileName = chat.audio.toString();

      if (chat.document != null) {
        // var bits = chat.filePath.toString().split('/');
        var decoded = Uri.decodeFull(chat.audio.toString());
        var split = decoded.split('/');
        fileName = split[split.length - 1];
        if (fileName.contains('?')) {
          split = fileName.split('?');
          fileName = split[0];
        }
      }

      return InkWell(
        onTap: () async {
          if (encodedFileName.isURL) {
            Get.to(() => Player(
                  audioFile: encodedFileName,
                  fileName: fileName,
                ));
          } else {
            OpenFile.open(encodedFileName);
          }
        },
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              mainAxisSize: MainAxisSize.min,
              children: [
                Flexible(
                  fit: FlexFit.loose,
                  child: Column(
                    children: [
                      Text(
                        'Audio File',
                        style: CustomTextStyles.medium(
                            fontSize: 12.0,
                            fontColor: Colors.black,
                            isUnderLine: true),
                      ),
                      if (fileName != null)
                        Text(
                          '$fileName',
                          style: CustomTextStyles.normal(
                              fontSize: 8.0, fontColor: Colors.black),
                        ),
                    ],
                  ),
                ),
                const SizedBox(width: 5),
                Container(
                  height: 35,
                  width: 35,
                  decoration: BoxDecoration(
                    color: Colors.grey,
                    borderRadius: BorderRadius.circular(40),
                  ),
                  child: const Icon(
                    Icons.audiotrack,
                    color: Colors.white,
                    size: 20,
                  ),
                ),
              ],
            ),
          ],
        ),
      );
    } else if (chat.type == "document") {
      var encodedFileName = chat.document.toString();

      if (chat.document != null) {
        // var bits = chat.filePath.toString().split('/');
        var decoded = Uri.decodeFull(chat.document.toString());
        var split = decoded.split('/');
        fileName = split[split.length - 1];
        if (fileName.contains('?')) {
          split = fileName.split('?');
          fileName = split[0];
        }
      }

      return InkWell(
        onTap: () async {
          if (encodedFileName.isURL) {
            if (!await launchUrl(
              Uri.parse(encodedFileName),
              mode: LaunchMode.externalApplication,
            )) {
              throw 'Could not launch $encodedFileName';
            }
          } else {
            OpenFile.open(encodedFileName);
          }
        },
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              mainAxisSize: MainAxisSize.min,
              children: [
                Flexible(
                  fit: FlexFit.loose,
                  child: Column(
                    children: [
                      Text(
                        'Document File',
                        style: CustomTextStyles.medium(
                            fontSize: 12.0,
                            fontColor: Colors.black,
                            isUnderLine: true),
                      ),
                      if (fileName != null)
                        Text(
                          '$fileName',
                          style: CustomTextStyles.normal(
                              fontSize: 8.0, fontColor: Colors.black),
                        ),
                    ],
                  ),
                ),
                const SizedBox(width: 5),
                Container(
                  height: 35,
                  width: 35,
                  decoration: BoxDecoration(
                    color: Colors.grey,
                    borderRadius: BorderRadius.circular(40),
                  ),
                  child: const Icon(
                    Icons.attach_file,
                    color: Colors.white,
                    size: 20,
                  ),
                ),
              ],
            ),
          ],
        ),
      );
    } else if (chat.type == "image") {
      print(chat.message);
      return InkWell(
        onTap: () {
          Get.dialog(
            ImagePreview(image: chat.image),
          );
        },
        child: ClipRRect(
          borderRadius: BorderRadius.circular(10),
          child: Container(
              height: 200,
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(10),
              ),
              child: chat.image!.isURL
                  ? Hero(
                      tag: 'htg_$index',
                      child: FadeInImage.assetNetwork(
                        placeholder: ImageResource.groupPlaceHolder,
                        imageErrorBuilder: (c, o, s) {
                          return Image.network(ImageResource.groupPlaceHolder,
                              height: 40, width: 40);
                        },
                        // image: FileImage(File(chat.image)),
                        image: chat.image!,
                      ),
                    )
                  : Image.file(
                      File(chat.image!),
                    )
              // Hero(
              //   tag: 'htg_$index',
              //   child: chat.image!.isURL
              //       ? FadeInImage.assetNetwork(
              //           placeholder: ImageResource.groupPlaceHolder,
              //           imageErrorBuilder: (c, o, s) {
              //             print("IMAGERROR_MESSSAGE_TYPE_IMAGE");
              //             return Image.network(ImageResource.groupPlaceHolder,
              //                 height: 40, width: 40);
              //           },
              //           // image: FileImage(File(chat.image)),
              //           image: image,
              //         )
              //       : Image.memory(
              //           Uint8List.fromList(image),
              //         ),
              // ),
              ),
        ),
      );
    } else if (chat.type == "video") {
      return InkWell(
        onTap: () {
          Get.to(() => const VideoPlayerView(),
              arguments: [chat.video, chat.video!.isURL]);
        },
        child: ClipRRect(
          borderRadius: BorderRadius.circular(10),
          child: Stack(
            alignment: AlignmentDirectional.center,
            children: [
              Container(
                  height: 200,
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(10),
                  ),
                  child: chat.thumbnail!.isURL
                      ? Hero(
                          tag: 'htg_$index',
                          child: FadeInImage.assetNetwork(
                            placeholder: ImageResource.groupPlaceHolder,
                            imageErrorBuilder: (c, o, s) {
                              return Image.network(
                                  ImageResource.groupPlaceHolder,
                                  height: 40,
                                  width: 40);
                            },
                            // image: FileImage(File(chat.image)),
                            image: chat.thumbnail!,
                          ),
                        )
                      : Image.file(
                          File(chat.thumbnail!),
                        )),
              const Icon(Icons.play_circle)
            ],
          ),
        ),
      );
    }
  }

  TextEditingController messageSendController = TextEditingController();
  var sendButtonEnable = false.obs;

  messageSendView() {
    return Container(
      padding: const EdgeInsets.only(top: 6, bottom: 6),
      decoration: const BoxDecoration(color: Color(0xffD1D1D5)),
      child: Row(
        children: [
          IconButton(
              onPressed: () {
                showAttachDialog();
              },
              icon: const Icon(Icons.attach_file)),
          Expanded(
              child: TextField(
            // readOnly: true,
            controller: messageSendController,
            onChanged: (text) async {
              if (text.isEmpty) {
                sendButtonEnable.value = false;
              } else {
                sendButtonEnable.value = true;
              }
            },
            // autofocus: uc.isMicTap.value,
            // focusNode: inputFocus,
            maxLines: 7,
            minLines: 1,
            style: const TextStyle(
              // fontFamily: Styles.FontNameRegular,
              color: Colors.black,
            ),
            textInputAction: TextInputAction.newline,
            decoration: InputDecoration(
              fillColor: Colors.white,
              filled: true,
              contentPadding: const EdgeInsets.only(left: 10, right: 10),
              hintText: "Type a message",
              border: OutlineInputBorder(
                borderRadius: BorderRadius.circular(6),
                borderSide: BorderSide.none,
              ),
            ),
          )),
          Obx(
            () => IconButton(
                onPressed: sendButtonEnable.value
                    ? () {
                        var data = {
                          'type': "text",
                          'image': "",
                          'thumbnail': "",
                          'audio': "",
                          "base64Thumbnail": "",
                          "document": "",
                          "isRead": true,
                          "message": messageSendController.text,
                          'msgId': "10",
                          "readBy": "",
                          "secretKey": "",
                          "sentAt": {
                            'seconds':
                                (DateTime.now().millisecondsSinceEpoch ~/ 1000),
                            "nanoseconds": ""
                          },
                          "sentBy": myUserId,
                          "video": "",
                        };
                        setState(() {
                          var dataS = {
                            "msg": messageSendController.text,
                            "rid": grpId,
                            "type": "text",
                            "name": ""
                          };
                          sendMessage(dataS);
                          messageData.add(data);
                          messageSendController.clear();
                          sendButtonEnable.value = false;
                        });
                      }
                    : null,
                icon: Icon(
                  Icons.send_sharp,
                  color: sendButtonEnable.value ? Colors.black : Colors.black12,
                )),
          )
        ],
      ),
    );
  }

  void showAttachDialog() {
    var alert = Align(
      alignment: Alignment.bottomCenter,
      child: BackdropFilter(
        filter: ImageFilter.blur(sigmaX: 3, sigmaY: 3),
        child: Padding(
          padding: const EdgeInsets.all(8),
          child: Container(
            width: Get.width / 1.2,
            margin: const EdgeInsets.only(bottom: 30, left: 12, right: 12),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
              color: Colors.white,
            ),
            child: Material(
              color: Colors.transparent,
              borderRadius: BorderRadius.circular(10),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Align(
                    alignment: Alignment.topRight,
                    child: IconButton(
                      icon: const Icon(Icons.clear),
                      onPressed: () => Get.back(),
                    ),
                  ),
                  dialogTile(
                      text: 'Send Attachment',
                      fontWeight: FontWeight.bold,
                      fontSize: 18),
                  saperator(),
                  dialogTile(
                      text: 'Gallery',
                      callback: () {
                        pickImage(true);
                      }),
                  saperator(),
                  dialogTile(
                      text: 'Camera',
                      callback: () {
                        pickImage(false);
                      }),
                  saperator(),
                  dialogTile(
                      text: 'Document',
                      callback: () {
                        attachDocument();
                      }),
                ],
              ),
            ),
          ),
        ),
      ),
    );

    showGeneralDialog(
      barrierLabel: "Label",
      barrierDismissible: true,
      barrierColor: Colors.black.withOpacity(0.5),
      transitionDuration: const Duration(milliseconds: 400),
      context: context,
      pageBuilder: (context, anim1, anim2) {
        return alert;
      },
      transitionBuilder: (context, anim1, anim2, child) {
        return SlideTransition(
          position: Tween(begin: const Offset(0, 1), end: const Offset(0, 0))
              .animate(anim1),
          child: child,
        );
      },
    );
  }

  dialogTile(
      {required String text,
      Function? callback,
      fontWeight = FontWeight.normal,
      double fontSize = 16}) {
    return InkWell(
      onTap: () {
        if (callback != null) {
          Get.back();
          callback();
        }
      },
      child: Container(
        width: Get.width,
        alignment: Alignment.center,
        child: Padding(
          padding: const EdgeInsets.only(
              right: 12.0, left: 12.0, top: 16, bottom: 16),
          child: Text(
            text,
            style: TextStyle(
              fontSize: fontSize,
              fontWeight: fontWeight,
            ),
          ),
        ),
      ),
    );
  }

  saperator() {
    return Padding(
        padding: const EdgeInsets.only(left: 24, right: 24),
        child: Container(height: 1, color: Colors.grey));
  }

  Future pickImage(gallery) async {
    ImagePicker picker = ImagePicker();
    var pickedFile;

    if (gallery) {
      FilePickerResult? result = await FilePicker.platform.pickFiles(
        type: FileType.media,
        withData: true,
      );
      var bytes = result!.files[0].bytes;
      var imageName = result.files[0].name;
      pickedFile = File(result.paths[0].toString());

      var thumbnail;
      if (result.names.toString().split(".").last.contains("mp4")) {
        thumbnail = await VideoThumbnail.thumbnailFile(
            video: result.paths[0].toString(), imageFormat: ImageFormat.JPEG);
      }

      var dataS = {
        result.names.toString().split(".").last.contains("mp4")
            ? "video"
            : "image": bytes,
        "rid": grpId,
        "type": result.names.toString().split(".").last.contains("mp4")
            ? "video"
            : "image",
        "name": imageName
      };

      sendMessage(dataS);
      var data = {
        'type': result.names.toString().split(".").last.contains("mp4")
            ? "video"
            : "image",
        'image': !result.names.toString().split(".").last.contains("mp4")
            ? pickedFile.path
            : "",
        'thumbnail': !result.names.toString().split(".").last.contains("mp4")
            ? thumbnail
            : "",
        'audio': "",
        "base64Thumbnail": "",
        "document": "",
        "isRead": true,
        "message": bytes.toString(),
        'msgId': "10",
        "readBy": "",
        "secretKey": "",
        "sentAt": {
          'seconds': (DateTime.now().millisecondsSinceEpoch ~/ 1000),
          "nanoseconds": ""
        },
        "sentBy": myUserId,
        "video": result.names.toString().split(".").last.contains("mp4")
            ? pickedFile.path
            : "",
      };
      setState(() {
        messageData.add(data);
      });
    }

    // Otherwise open camera to get new photo
    else {
      final XFile? image = await picker.pickImage(
        source: ImageSource.camera,
        imageQuality: 80,
      );
      var bytes = File(image!.path).readAsBytes();
      print(bytes);
      var imageName = image.name;
      pickedFile = File(image.path.toString());
      var dataS = {
        "image": bytes,
        "rid": grpId,
        "type": "image",
        "name": imageName
      };

      sendMessage(dataS);
      var data = {
        'type': "image",
        'image': pickedFile.path,
        'thumbnail': "",
        'audio': "",
        "base64Thumbnail": "",
        "document": "",
        "isRead": true,
        "message": bytes.toString(),
        'msgId': "10",
        "readBy": "",
        "secretKey": "",
        "sentAt": {
          'seconds': (DateTime.now().millisecondsSinceEpoch ~/ 1000),
          "nanoseconds": ""
        },
        "sentBy": myUserId,
        "video": "",
      };
      setState(() {
        messageData.add(data);
      });
    }
  }

  File? file;

  void attachDocument() async {
    var pickedFile;
    FilePickerResult? result = await FilePicker.platform.pickFiles(
      type: FileType.custom,
      allowedExtensions: ['txt', 'pdf', 'doc', 'xlsx', 'mp3'],
    );

    if (result != null) {
      var bytes = result.files[0].bytes;
      var imageName = result.files[0].name;
      pickedFile = File(result.paths[0].toString());
      print(result.files[0].bytes);
      var dataS = {
        result.names.toString().split(".").last.contains("mp3")
            ? "audio"
            : "document": bytes,
        "rid": grpId,
        "type": result.names.toString().split(".").last.contains("mp3")
            ? "audio"
            : "document",
        "name": imageName
      };

      sendMessage(dataS);
      var data = {
        'type': result.names.toString().split(".").last.contains("mp3")
            ? "audio"
            : "document",
        'image': "",
        'thumbnail': "",
        'audio': result.names.toString().split(".").last.contains("mp3")
            ? pickedFile.path
            : "",
        "base64Thumbnail": "",
        "document": !result.names.toString().split(".").last.contains("mp3")
            ? pickedFile.path
            : "",
        "isRead": true,
        "message": bytes.toString(),
        'msgId': "10",
        "readBy": "",
        "secretKey": "",
        "sentAt": {
          'seconds': (DateTime.now().millisecondsSinceEpoch ~/ 1000),
          "nanoseconds": ""
        },
        "sentBy": myUserId,
        "video": "",
      };
      setState(() {
        messageData.add(data);
      });
    } else {
      // Future.delayed(Duration.zero, () => uc.sendingUiLoader.value = false);
      // User canceled the picker
      print('User canceled the picker');
    }
  }

  Future shareLocation() async {
    Position position = await Geolocator.getCurrentPosition(
        desiredAccuracy: LocationAccuracy.low);
    // final coordinates = new Coordinates(position.latitude, position.longitude);
    // var addresses =
    //     await Geocoder.local.findAddressesFromCoordinates(coordinates);
    // var first = addresses.first;
    // Map<String, dynamic> msgData = Map();
    // msgData['viewBy'] = [
    //   SessionImpl.getFirebaseUserId(),
    //   opponentUserModel.userId
    // ];
    // msgData['isRead'] = false;
    // msgData['location'] = first.addressLine;
    // msgData['latlng'] = '${position.latitude},${position.longitude}';
    // msgData['readBy'] = opponentUserModel.userId;
    // msgData['sentAt'] = DateTime.now().toString();
    // msgData['sentBy'] = SessionImpl.getFirebaseUserId();
    // msgData['timeMilliSeconds'] = DateTime.now().millisecondsSinceEpoch;
    // msgData['type'] = 'location';
    // await uc.fStore.sendMessage(opponentUserModel.groupId, msgData, () {
    //   // getChatMessages();
    // });
  }
}
