import 'dart:io';

import 'package:agschat_example/core/services/stream_socket.dart';
import 'package:agschat_example/helper/custom_styles.dart';
import 'package:agschat_example/model/profile_detail_model.dart';
import 'package:agschat_example/view/widgets/comman.dart';
import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ProfileView extends StatefulWidget {
  const ProfileView({Key? key}) : super(key: key);

  @override
  State<ProfileView> createState() => _ProfileViewState();
}

class _ProfileViewState extends State<ProfileView> {
  TextEditingController txtUserName = TextEditingController();
  @override
  void initState() {
    super.initState();
    getUserProfile();
  }

  var imageBytes;
  var profileImage = File("").obs;
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      bottomNavigationBar: SafeArea(
        child: GestureDetector(
          onTap: () {
            if (txtUserName.text.isNotEmpty) {
              updateProfile(name: txtUserName.text, profilePic: imageBytes);
            } else {}
          },
          child: Container(
            height: 50,
            margin: const EdgeInsets.only(top: 16, left: 20, right: 20),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(8.0),
              color: Colors.blue,
            ),
            child: Center(
              child: Text(
                "Save",
                style: CustomTextStyles.semiBold(
                    fontSize: 18.0, fontColor: Colors.white),
              ),
            ),
          ),
        ),
      ),
      body: SafeArea(
        child: Column(
          children: [
            appBar(),
            StreamBuilder(
                stream: profileViewSocket.getResponse,
                builder:
                    (BuildContext context, AsyncSnapshot<dynamic> snapshot) {
                  print(snapshot.data);
                  ProfileDetailModel? profileData;
                  if (snapshot.data != null) {
                    profileData = ProfileDetailModel(
                        userId: snapshot.data['userId'],
                        mobileEmail: snapshot.data['mobileEmail'],
                        name: snapshot.data['name'],
                        profilePicture: snapshot.data['profilePicture']);
                    txtUserName.text = profileData.name;
                  }
                  return Container(
                    padding: const EdgeInsets.only(left: 20, right: 20),
                    width: Get.width,
                    color: Colors.white,
                    child: Column(
                      children: [
                        const SizedBox(
                          height: 24,
                        ),
                        Stack(
                          alignment: AlignmentDirectional.center,
                          children: [
                            GestureDetector(
                                onTap: () async {
                                  var pickedFile;
                                  FilePickerResult? result =
                                      await FilePicker.platform.pickFiles(
                                    type: FileType.media,
                                    withData: true,
                                  );
                                  imageBytes = result!.files[0].bytes;
                                  pickedFile = File(result.paths[0].toString());
                                  profileImage.value = pickedFile;
                                },
                                child: Obx(() => !profileImage.value.isAbsolute
                                    ? Common.profileNetworkImage(
                                        borderRadius: 200.0,
                                        height: 200.0,
                                        width: 200.0,
                                        imageUrl: profileData!.profilePicture,
                                      )
                                    : ClipRRect(
                                        borderRadius:
                                            BorderRadius.circular(200),
                                        child: Container(
                                          color: Colors.black12,
                                          child: Image.file(
                                            File(
                                              profileImage.value.path,
                                            ),
                                            height: 200.0,
                                            width: 200.0,
                                          ),
                                        )))),
                            const Icon(
                              Icons.camera_alt_outlined,
                              color: Colors.white,
                              size: 30.0,
                            )
                          ],
                        ),
                        const SizedBox(
                          height: 32,
                        ),
                        TextField(
                          controller: txtUserName,
                          decoration: InputDecoration(
                            hintText: "Enter User Name",
                            hintStyle: CustomTextStyles.medium(
                                fontSize: 14.0, fontColor: Colors.black38),
                            filled: true,
                            fillColor: const Color(0xffEEEEEF),
                            border: searchCommonBorderStyle,
                            enabledBorder: searchCommonBorderStyle,
                            disabledBorder: searchCommonBorderStyle,
                            focusedBorder: searchCommonBorderStyle,
                            focusedErrorBorder: searchCommonBorderStyle,
                            errorBorder: searchCommonBorderStyle,
                            contentPadding:
                                const EdgeInsets.only(left: 6, right: 6),
                          ),
                        ),
                        const SizedBox(
                          height: 8,
                        ),
                        Text(
                          "This is not your username or pin. This name will be visible to your chat contact.",
                          style: CustomTextStyles.normal(
                              fontSize: 14.0, fontColor: Colors.black54),
                        ),
                        const SizedBox(
                          height: 16,
                        ),
                      ],
                    ),
                  );
                }),
            const SizedBox(
              height: 10,
            ),
          ],
        ),
      ),
    );
  }

  var searchCommonBorderStyle = const OutlineInputBorder(
    borderSide: BorderSide(
      color: Color(0xffE6E6E6),
    ),
  );

  Widget appBar() {
    return Container(
      color: const Color(0xffE5E5EA),
      child: Row(
        children: [
          IconButton(
              onPressed: () {
                Get.back();
              },
              icon: const Icon(
                Icons.arrow_back_outlined,
                size: 25.0,
              )),
          const SizedBox(
            width: 8,
          ),
          Text(
            "Profile",
            style: CustomTextStyles.medium(
                fontSize: 18.0, fontColor: Colors.black),
          ),
        ],
      ),
    );
  }
}
