import 'package:agschat_example/helper/images.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class Common {
  static getSnackToast({
    title = "Error",
    message = '',
    snackPosition: SnackPosition.TOP,
    backgroundColor = Colors.black,
    colorText = Colors.white,
    Widget? icon,
    Duration? duration,
    Function? onTapSnackBar,
    Function? onTapButton,
    bool withButton = false,
    buttonText = 'Ok',
    Function? onDismissed,
  }) {
    Get.snackbar(
      title,
      message,
      mainButton: withButton
          ? TextButton(
              onPressed: () {
                if (onTapButton != null) onTapButton();
              },
              child: Text(buttonText))
          : null,
      onTap: (tap) {
        if (onTapSnackBar != null) onTapSnackBar(tap);
      },
      duration: duration,
      snackPosition: snackPosition,
      backgroundColor: backgroundColor,
      icon: icon,
      colorText: colorText,
      snackbarStatus: (status) {
        print(status);
        if (status == SnackbarStatus.CLOSED) {
          if (onDismissed != null) onDismissed();
        }
      },
    );
  }

  static profileNetworkImage({
    height = 50.0,
    width = 50.0,
    isShowBorder = false,
    borderWidth = 1.5,
    showBoxShadow = false,
    borderRadius = 40.0,
    backgroundColor,
    placeHolder = ImageResource.profilePlaceHolder,
    imageUrl = "",
  }) {
    return Container(
      height: height,
      width: width,
      decoration: BoxDecoration(
          color: backgroundColor ?? Colors.black12,
          shape: BoxShape.circle,
          border: Border.all(
              color: isShowBorder ? Colors.white : Colors.transparent,
              width: borderWidth),
          boxShadow: showBoxShadow
              ? [
                  BoxShadow(
                    color: Color(0xff000000).withOpacity(0.10),
                    blurRadius: 10.0,
                    spreadRadius: 1.0,
                  )
                ]
              : []),
      child: ClipRRect(
        borderRadius: BorderRadius.circular(borderRadius),
        child: CachedNetworkImage(
          fadeInDuration: Duration(milliseconds: 250),
          imageUrl: imageUrl == "" ? "" : imageUrl,
          errorWidget: (context, url, error) => Opacity(
            opacity: 0.9,
            child: ClipRRect(
              borderRadius: BorderRadius.circular(30.0),
              child: Image.asset(
                placeHolder,
                height: height,
                width: width,
              ),
            ),
          ),
          fit: BoxFit.cover,
          placeholder: ((context, String s) => Image.asset(
                placeHolder,
                height: height,
                width: width,
              )),
        ),
      ),
    );
  }
}
