import 'dart:ui';

import 'package:agschat/src/helper/custom_styles.dart';
import 'package:audioplayers/audioplayers.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class Player extends StatefulWidget {
  const Player({
    Key? key,
    this.audioFile,
    this.fileName,
  }) : super(key: key);
  final String? audioFile;
  final String? fileName;
  @override
  _PlayerState createState() => _PlayerState();
}

class _PlayerState extends State<Player> {
  AudioPlayer audioPlayer = AudioPlayer();
  var audioPlay = false.obs;

  @override
  void initState() {
    print(widget.audioFile);
    playAudio(widget.audioFile);
    super.initState();
  }

  @override
  void dispose() {
    audioPlayer.pause();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.transparent,
      body: Container(
        padding: const EdgeInsets.symmetric(horizontal: 16),
        child: InkWell(
          highlightColor: Colors.transparent,
          splashColor: Colors.transparent,
          onTap: () {
            Get.back();
          },
          child: BackdropFilter(
            filter: ImageFilter.blur(sigmaX: 3, sigmaY: 3),
            child: Align(
              alignment: Alignment.center,
              child: Column(
                mainAxisSize: MainAxisSize.min,
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: [
                      IconButton(
                        onPressed: () {
                          Get.back();
                        },
                        icon: const Icon(
                          Icons.clear,
                          color: Colors.white,
                        ),
                      )
                    ],
                  ),
                  Center(
                    child: Container(
                      padding: const EdgeInsets.symmetric(
                          vertical: 10, horizontal: 10),
                      decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(6.0),
                        color: Colors.grey,
                      ),
                      child: Row(
                        children: [
                          InkWell(
                            onTap: () {
                              if (audioPlayer.state == PlayerState.paused ||
                                  audioPlayer.state == PlayerState.stopped) {
                                playAudio(widget.audioFile);
                              } else {
                                paused();
                              }
                            },
                            child: Container(
                              height: 60,
                              width: 60,
                              decoration: BoxDecoration(
                                  shape: BoxShape.circle,
                                  gradient: LinearGradient(
                                    begin: Alignment.bottomLeft,
                                    end: Alignment.topRight,
                                    colors: [
                                      Color(0xffFFFFFF),
                                      Color(0xffFFFFFF).withOpacity(0.1),
                                    ],
                                  ),
                                  border: Border.all(
                                      width: 1.5, color: Colors.white)),
                              child: Padding(
                                padding: const EdgeInsets.all(16),
                                child: Obx(() => Icon(audioPlay.value
                                    ? Icons.pause
                                    : Icons.play_arrow)),
                              ),
                            ),
                          ),
                          Expanded(
                            child: Column(
                              children: [
                                Text(
                                  "Audio File",
                                  style: CustomTextStyles.medium(
                                    fontSize: 16.0,
                                    fontColor: Colors.black,
                                  ),
                                ),
                                Text(
                                  "${widget.fileName}",
                                  style: CustomTextStyles.medium(
                                    fontSize: 16.0,
                                    fontColor: Colors.black,
                                  ),
                                  textAlign: TextAlign.center,
                                  maxLines: 2,
                                  overflow: TextOverflow.ellipsis,
                                )
                              ],
                            ),
                          )
                        ],
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  playAudio(audioUrl) async {
    await audioPlayer.play(UrlSource(audioUrl));
    /* When audio completed audio is Stopped */
    audioPlayer.onPlayerComplete.listen((event) {
      setState(() {
        audioPlayer.stop();
      });
      audioPlay.value = false;
      print("AUDIO COMPLETED PLAYING");
    });
    audioPlay.value = true;
  }

  paused() async {
    await audioPlayer.pause();
    // if (result == 1) {
    //   print("Play Audio");
    // }
    audioPlay.value = false;
  }
}
