import 'package:agschat/src/constants.dart';
import 'package:agschat/src/core/services/stream_socket.dart';
import 'package:agschat/src/helper/colors.dart';
import 'package:agschat/src/helper/custom_styles.dart';
import 'package:agschat/src/helper/images.dart';
import 'package:agschat/src/view/widgets/comman.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class GroupInfoView extends StatefulWidget {
  const GroupInfoView({Key? key}) : super(key: key);

  @override
  State<GroupInfoView> createState() => _GroupInfoViewState();
}

class _GroupInfoViewState extends State<GroupInfoView> {
  var groupDetails;
  var groupName = "".obs;
  var participentCounts = "".obs;
  var participentList = [].obs;
  var createdBy = "".obs;
  var groupImage = "".obs;
  var groupId = "".obs;
  @override
  void initState() {
    if (Get.arguments != null) {
      groupDetails = Get.arguments;
      print(groupDetails);
      print(groupDetails['profilePicture']);
      createdBy.value = groupDetails['createdBy'];
      groupName.value = groupDetails['name'];
      participentList.value = groupDetails['users'];
      groupImage.value = groupDetails['groupImage'] ?? "";
      groupId.value = groupDetails['groupId'];
    }
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      body: SafeArea(
        child: Container(
          color: const Color(0xffE5E5EA),
          child: Obx(
            () => Column(
              children: [
                appBar(),
                Container(
                  width: Get.width,
                  color: Colors.white,
                  child: Column(
                    children: [
                      const SizedBox(
                        height: 24,
                      ),
                      Common.profileNetworkImage(
                        borderRadius: 200.0,
                        height: 200.0,
                        width: 200.0,
                        placeHolder: ImageResource.groupPlaceHolder,
                        imageUrl: groupImage.value,
                      ),
                      const SizedBox(
                        height: 16,
                      ),
                      Text(
                        groupName.value,
                        style: CustomTextStyles.medium(
                            fontSize: 26.0, fontColor: Colors.black),
                      ),
                      const Padding(
                        padding: EdgeInsets.only(top: 10.0, bottom: 10.0),
                        child: Divider(color: Colors.black26, height: 1.0),
                      ),
                      Text(
                        "Group - ${participentList.length} participants",
                        style: CustomTextStyles.normal(
                            fontSize: 20.0, fontColor: Colors.black),
                      ),
                      const SizedBox(
                        height: 16,
                      ),
                    ],
                  ),
                ),
                const SizedBox(
                  height: 10,
                ),
                Expanded(
                  child: Container(
                    color: Colors.white,
                    child: Column(
                      children: [
                        Padding(
                          padding: const EdgeInsets.only(
                              left: 12.0, right: 12.0, top: 16.0, bottom: 16.0),
                          child: Row(
                            mainAxisAlignment: MainAxisAlignment.spaceBetween,
                            children: [
                              Text(
                                "${participentList.length} participants",
                                style: CustomTextStyles.medium(
                                    fontSize: 16.0,
                                    fontColor: const Color(0xff667B88)),
                              ),
                              Text(
                                "+ Add Member",
                                style: CustomTextStyles.medium(
                                    fontSize: 16.0,
                                    fontColor: const Color(0xff0F659E)),
                              )
                            ],
                          ),
                        ),
                        Expanded(
                          child: ListView.separated(
                              padding: const EdgeInsets.only(
                                  left: 12.0, right: 12.0),
                              itemBuilder: (context, index) {
                                return Row(
                                  children: [
                                    Common.profileNetworkImage(
                                      borderRadius: 56.0,
                                      height: 56.0,
                                      width: 56.0,
                                      placeHolder:
                                          ImageResource.profilePlaceHolder,
                                      imageUrl: participentList[index]
                                              ['profile_picture'] ??
                                          "",
                                    ),
                                    const SizedBox(width: 10.0),
                                    Expanded(
                                      child: Text(
                                        participentList[index]['userId'] ==
                                                myUserId
                                            ? participentList[index]['name'] +
                                                " (You)"
                                            : participentList[index]['name'],
                                        style: CustomTextStyles.medium(
                                            fontSize: 14.0,
                                            fontColor: Colors.black),
                                        overflow: TextOverflow.ellipsis,
                                      ),
                                    ),
                                    participentList[index]['userId'] ==
                                            createdBy.value
                                        ? Container(
                                            decoration: BoxDecoration(
                                              borderRadius:
                                                  BorderRadius.circular(4),
                                              color: themeColor,
                                            ),
                                            padding: const EdgeInsets.symmetric(
                                                vertical: 6, horizontal: 6),
                                            child: Text(
                                              "Admin",
                                              style: CustomTextStyles.normal(
                                                fontSize: 10.0,
                                                fontColor: Color(0xff0F659E),
                                              ),
                                            ),
                                          )
                                        : Container(
                                            decoration: BoxDecoration(
                                              borderRadius:
                                                  BorderRadius.circular(4),
                                              color: const Color(0xffFFE2E5),
                                            ),
                                            padding: const EdgeInsets.symmetric(
                                                vertical: 6, horizontal: 6),
                                            child: Text(
                                              "Remove",
                                              style: CustomTextStyles.normal(
                                                fontSize: 10.0,
                                                fontColor:
                                                    const Color(0xffF64E89),
                                              ),
                                            ),
                                          )
                                  ],
                                );
                              },
                              separatorBuilder: (context, index) {
                                return const SizedBox(height: 16);
                              },
                              itemCount: participentList.length),
                        ),
                      ],
                    ),
                  ),
                ),
                const SizedBox(height: 10),
                InkWell(
                  onTap: () {
                    exitGroup(userId: myUserId, groupId: groupId.value);
                  },
                  child: Container(
                    color: Colors.white,
                    padding: const EdgeInsets.all(20),
                    width: Get.width,
                    child: Row(
                      children: [
                        const Icon(
                          Icons.login,
                          color: Colors.red,
                        ),
                        const SizedBox(
                          width: 8,
                        ),
                        Text(
                          "Exit Group",
                          style: CustomTextStyles.medium(
                              fontSize: 16.0, fontColor: Colors.red),
                        )
                      ],
                    ),
                  ),
                ),
                const SizedBox(
                  height: 10,
                ),
                createdBy.value == myUserId
                    ? Container(
                        color: Colors.white,
                        padding: const EdgeInsets.all(20),
                        width: Get.width,
                        child: Row(
                          children: [
                            const Icon(
                              Icons.delete,
                              color: Colors.red,
                            ),
                            const SizedBox(
                              width: 8,
                            ),
                            Text(
                              "Delete Group",
                              style: CustomTextStyles.medium(
                                  fontSize: 16.0, fontColor: Colors.red),
                            )
                          ],
                        ),
                      )
                    : const SizedBox.shrink()
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget appBar() {
    return Row(
      children: [
        IconButton(
            onPressed: () {
              Get.back();
            },
            icon: const Icon(
              Icons.clear,
              size: 30.0,
            )),
        const SizedBox(
          width: 8,
        ),
        Text(
          "Group Info",
          style:
              CustomTextStyles.medium(fontSize: 18.0, fontColor: Colors.black),
        ),
      ],
    );
  }
}
